---
title: Comparing_cbps_in_r_vs_python_using_sim_data
sidebar_position: 6
hide_table_of_contents: true
hide_title: true
---

import HTMLLoader from '@site/src/components/HTMLLoader';
import useBaseUrl from '@docusaurus/useBaseUrl';

Link to notebook: [comparing_cbps_in_r_vs_python_using_sim_data.ipynb](https://github.com/facebookresearch/balance/blob/main/tutorials/comparing_cbps_in_r_vs_python_using_sim_data.ipynb)

<HTMLLoader docFile={useBaseUrl('html/tutorials/comparing_cbps_in_r_vs_python_using_sim_data.html')}/>
